Process command line arguments, allowing scripts to behave like functions, with well-defined inputs and outputs. Helps make data analysis workflows more modular, and therefore more transparent, flexible, and reliable.
Details
cmd_assign()Process command line argumentsuse_renv()Activate a renv project before loading packagesextract_shell()Turn acmd_assign()call into a shell commandextract_make()Turn acmd_assign()call into a Makefile ruleshell_script()Create a shell scriptmakefile()Create a MakefileQuick Start How to use
cmd_assign()Modular Workflows for Data Analysis Safe, flexible data analysis workflows
Using command with renv Running pipeline scripts with renv
Author
Maintainer: John Bryant john@bayesiandemography.com
Authors:
John Bryant john@bayesiandemography.com
Other contributors:
Bayesian Demography Limited [copyright holder]