command-package: command: Process command line arguments

command-packageR Documentation

command: Process command line arguments

Description

Process arguments passed at the command line, as part of data analysis workflow.

Details

  • cmd_assign() Process command line arguments

  • extract_shell() Turn a cmd_assign() call into a shell command

  • extract_make() Turn a cmd_assign() call into a Makefile rule

  • shell_script() Create a shell script

  • makefile() Create a Makefile

  • Quick Start Guide How to use cmd_assign()

  • Modular Workflows for Data Analysis Safe, flexible data analysis workflows

Author(s)

Maintainer: John Bryant john@bayesiandemography.com

Other contributors:

  • Bayesian Demography Limited [copyright holder]

See Also

Useful links:


command documentation built on Nov. 5, 2025, 7 p.m.